@@ -36,7 +36,7 @@ import sys
 from PIL import Image, ExifTags, IptcImagePlugin
 import pystache
 
-__version__ = '0.3'
+__version__ = '0.4'
 
 
 
@@ -132,6 +132,8 @@ class PhotoWebber(object):
             md_j['page_desc'] = [
               {'p': d.decode(self.enc)} for d in self.options.page_desc
             ]
+        if self.options.reverse:
+            md_j['reverse'] = True
         return md_j
 
     def run(self, photo_dir):
@@ -140,8 +142,17 @@ class PhotoWebber(object):
             self.error("Can't find %s" % photo_dir)
         sys.stdout.write("Running %s\n" % photo_dir)
 
-        pics, page_vars = self.get_sorted_pics(photo_dir)
         md_j = self.read_md(photo_dir)
+        page_vars = self.get_sorted_pics(photo_dir, md_j)
+        pics = page_vars['pics']
+        # TODO: error if no pics found.
+
+        # make the thumbnails
+        if self.tpl_md.get('thumbnails', False):
+            for pic in pics:
+                (pic['th_w'], pic['th_h']) = \
+                  self.make_thumbnail(photo_dir, pic)
+
         page_vars.update(md_j)
         self.create_columns(pics, page_vars)
 
@@ -156,11 +167,6 @@ class PhotoWebber(object):
         finally:
             gal_fd.close()
 
-        # make the thumbnails
-        if self.tpl_md.get('thumbnails', False) and not self.options.html:
-            for pic in pics:
-                self.make_thumbnail(photo_dir, pic)
-
         # write detail pages
         if self.tpl.get('detail', False):
             for pic in pics:
@@ -209,17 +215,20 @@ class PhotoWebber(object):
         height = self.tpl_md.get('thumbnail_h', 250)
         image.thumbnail((width, height), Image.ANTIALIAS)
         image.save(thumb_path, "JPEG")
+        return image.size
 
-    def get_sorted_pics(self, photo_dir):
+    def get_sorted_pics(self, photo_dir, md):
         "Get the pics and sort them"
         pics = self.load_pics(photo_dir)
         pics.sort(self.sort_pics)
+        if md.get('reverse', False): 
+            pics.reverse()
         for i in range(len(pics)):
             pics[i]['num'] = i + 1
         page_vars = {
             'pics': pics,
         }
-        return pics, page_vars
+        return page_vars
         
     @staticmethod
     def sort_pics(pic_a, pic_b):
@@ -234,18 +243,18 @@ class PhotoWebber(object):
             phile = os.path.join(photo_dir, phile)
             if os.path.splitext(phile)[1].lower() not in self.pic_types:
                 continue
-            md = self.mdget(phile)
+            md, (width, height) = self.mdget(phile)
             if md is None:
                 return
             path = os.path.split(phile)[1]
             pics.append({
                 'img_path': path,
                 'detail_path': "%s.html" % os.path.splitext(path)[0],
-                'title': md.get('Iptc.ObjectName', ''),
-                'caption': md.get('Iptc.Caption', ''),
+                'title': md.get('Iptc.ObjectName', '').decode('utf-8'),
+                'caption': md.get('Iptc.Caption', '').decode('utf-8'),
                 'date': md.get('Exif.DateTimeOriginal', ''),
-                'w': md.get('Exif.ExifImageWidth', ''),
-                'h': md.get('Exif.ExifImageHeight', ''),
+                'w': md.get('Exif.ExifImageWidth', width),
+                'h': md.get('Exif.ExifImageHeight', height),
             })
         return pics
 
@@ -267,7 +276,7 @@ class PhotoWebber(object):
         for tag, value in iptc_info.items():
             decoded = PhotoWebber._iptc_tags.get(tag, "unknown")
             out["Iptc." + decoded] = value
-        return out
+        return out, im.size
 
     @staticmethod
     def error(msg):
@@ -304,10 +313,10 @@ def photoweb_cli():
         help="Set the page's description"
     )
     option_parser.add_option(
-        "--html",
+        "-r",
         action="store_true",
-        dest="html",
-        help="Only generate HTML (not thumbnails)"
+        dest="reverse",
+        help="Reverse the order of the photos"
     )
     (options, args) = option_parser.parse_args()
     if len(args) < 1:
